.. Jirafs documentation master file, created by
   sphinx-quickstart on Wed Jul 23 16:31:07 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Jirafs's documentation!
==================================

.. image:: https://travis-ci.org/coddingtonbear/jirafs.svg?branch=master
    :target: https://travis-ci.org/coddingtonbear/jirafs

.. image:: https://badge.fury.io/py/jirafs.png
    :target: http://badge.fury.io/py/jirafs

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/coddingtonbear/python-myfitnesspal

Pronounced like 'giraffes', but totally unrelated to wildlife, this
library lets you stay out of Jira as much as possible by letting
you edit your Jira issues as a collection of text files using an
interface inspired by ``git`` and ``hg``.

.. image:: http://coddingtonbear-public.s3.amazonaws.com/github/jirafs/readme_demo_2.1_v7.gif

.. toctree::
   :maxdepth: 3

   getting_started
   migrating
   commands
   advanced_commands
   configuration
   plugins
   macros
   details


